==> gds-2.17.3.tar.gz: gds-2.17.3/SignalProcessing/dict/dmtsigp_linkdef.h <==
#ifdef __CINT__

#pragma link off all globals;
#pragma link off all classes;
#pragma link off all functions;
#pragma link off all templates;

#pragma link C++ class FilterBase;
#pragma link C++ enum Filter_Type;
#pragma link C++ class Pipe;
#pragma link C++ class auto_pipe;
#pragma link C++ class filter_delay;
#pragma link C++ class Chirp;
#pragma link C++ class Coherence;
#pragma link C++ class EFCLineFilter;
#pragma link C++ class RTXCorr;
#pragma link C++ class FIRFilter;
#pragma link C++ class FIRdft;
#pragma link C++ class IIRFilter;
#pragma link C++ class recolor;
#pragma link C++ class IIRSos;
#pragma link C++ class DecimateBy2;
#pragma link C++ class Difference;
#pragma link C++ class MultiPipe;
#pragma link C++ class Limiter;
#pragma link C++ class MathOp;
#pragma link C++ class MultiRate;
#pragma link C++ class Mixer;
#pragma link C++ class Blackman;
#pragma link C++ class FlatTop;
#pragma link C++ class Hanning;
#pragma link C++ class Hamming;
#pragma link C++ class Tukey;
#pragma link C++ class Uniform;
#pragma link C++ class Bartlett;
#pragma link C++ class BMH;
#pragma link C++ class Welch;
#pragma link C++ class GaussNoise;
#pragma link C++ class Inspiral;
#pragma link C++ class Offset;
#pragma link C++ class Sine;
#pragma link C++ class SquareWave;
#pragma link C++ class Triangle;
#pragma link C++ class Ramp;
#pragma link C++ class Impulse;
#pragma link C++ class Window;
#pragma link C++ class WelchPSD;
#pragma link C++ class SweptSine;
#pragma link C++ class Slope;
#pragma link C++ class LPEFilter;
// #pragma link C++ class slice; 
#pragma link C++ class LineFilter;
#pragma link C++ class FilterDesign;
#pragma link C++ class FDFilterBase;
#pragma link C++ class FDFilter;
#pragma link C++ class FDPipe;
#pragma link C++ class FDResample;
#pragma link C++ class Wavelet; 
#pragma link C++ class Haar<float>;
#pragma link C++ class Haar<double>;
#pragma link C++ class Biorthogonal<float>;
#pragma link C++ class Biorthogonal<double>;
#pragma link C++ class Daubechies<float>;
#pragma link C++ class Daubechies<double>;
#pragma link C++ class Symlet<float>;
#pragma link C++ class Symlet<double>;
#pragma link off class WaveDWT<float>;
#pragma link off class WaveDWT<double>;

#pragma link C++ function butter;
#pragma link C++ function cheby1;
#pragma link C++ function cheby2;
#pragma link C++ function ellip;
#pragma link C++ function notch;
#pragma link C++ function resgain;
#pragma link C++ function comb;
#pragma link C++ function pole;
#pragma link C++ function zero;
#pragma link C++ function pole2;
#pragma link C++ function zero2;
#pragma link C++ function zpk;
#pragma link C++ function limiter;
#pragma link C++ function multirate;
#pragma link C++ function resampling_factors_int;
#pragma link C++ function resampling_factors;

#pragma link C++ function Lagrange;
#pragma link C++ function Nevill(const double, int, double*, double*);
#pragma link C++ function Nevill(const double, int, float*, double*);

#pragma link C++ function design(double, int, dComplex*);
#pragma link C++ function dRemez(int, double, int, double*, double*, double*);
#pragma link C++ function dRemez(int, double, int, double*, double*, double*);
#pragma link C++ function dFirW(int, double, const char*, const char*, double, double, double, double);
#pragma link C++ function dFirW(int, double, const Window&, const char*, double, double);

#pragma link C++ function polyroot;
#pragma link C++ function polyexpand;

#pragma link C++ defined_in "iirutil.hh";
#pragma link C++ class FilterParse;

#endif

==> gds-2.18.5.tar.gz: gds-2.18.5/SignalProcessing/dict/dmtsigp_linkdef.h <==
#ifdef __CINT__

#pragma link off all globals;
#pragma link off all classes;
#pragma link off all functions;
#pragma link off all templates;
#pragma preprocess FilterBase.hh;

#pragma link C++ class FilterBase;
#pragma link C++ enum Filter_Type;
#pragma link C++ class Pipe;
#pragma link C++ class auto_pipe;
#pragma link C++ class filter_delay;
#pragma link C++ class Coherence;
#pragma link C++ class EFCLineFilter;
#pragma link C++ class RTXCorr;
#pragma link C++ class FIRFilter;
#pragma link C++ class FIRdft;
#pragma link C++ class IIRFilter;
#pragma link C++ class recolor;
#pragma link C++ class IIRSos;
#pragma link C++ class DecimateBy2;
#pragma link C++ class Difference;
#pragma link C++ class MultiPipe;
#pragma link C++ class Limiter;
#pragma link C++ class MathOp;
#pragma link C++ class MultiRate;
#pragma link C++ class Mixer;
#pragma link C++ class Blackman;
#pragma link C++ class FlatTop;
#pragma link C++ class Hanning;
#pragma link C++ class Hamming;
#pragma link C++ class Tukey;
#pragma link C++ class Uniform;
#pragma link C++ class Bartlett;
#pragma link C++ class BMH;
#pragma link C++ class Welch;
#pragma link C++ class window_api;
#pragma link C++ class WelchPSD;
#pragma link C++ class RayleighStat;
#pragma link C++ class SweptSine;
#pragma link C++ class Slope;
#pragma link C++ class LPEFilter;
// #pragma link C++ class slice; 
#pragma link C++ class LineFilter;
#pragma link C++ class FilterDesign;
#pragma link C++ class FDFilterBase;
#pragma link C++ class FDFilter;
#pragma link C++ class FDPipe;
#pragma link C++ class FDResample;
#pragma link C++ class Wavelet; 
#pragma link C++ class Haar<float>;
#pragma link C++ class Haar<double>;
#pragma link C++ class Biorthogonal<float>;
#pragma link C++ class Biorthogonal<double>;
#pragma link C++ class Daubechies<float>;
#pragma link C++ class Daubechies<double>;
#pragma link C++ class Symlet<float>;
#pragma link C++ class Symlet<double>;
#pragma link off class WaveDWT<float>;
#pragma link off class WaveDWT<double>;

#pragma link C++ function butter;
#pragma link C++ function cheby1;
#pragma link C++ function cheby2;
#pragma link C++ function ellip;
#pragma link C++ function notch;
#pragma link C++ function resgain;
#pragma link C++ function comb;
#pragma link C++ function pole;
#pragma link C++ function zero;
#pragma link C++ function pole2;
#pragma link C++ function zero2;
#pragma link C++ function zpk;
#pragma link C++ function limiter;
#pragma link C++ function multirate;
#pragma link C++ function resampling_factors_int;
#pragma link C++ function resampling_factors;

#pragma link C++ function Lagrange;
#pragma link C++ function Nevill(const double, int, double*, double*);
#pragma link C++ function Nevill(const double, int, float*, double*);

#pragma link C++ function design(double, int, dComplex*);
#pragma link C++ function dRemez(int, double, int, double*, double*, double*);
#pragma link C++ function dRemez(int, double, int, double*, double*, double*);
#pragma link C++ function dFirW(int, double, const char*, const char*, double, double, double, double);
#pragma link C++ function dFirW(int, double, const window_api&, const char*, double, double);

#pragma link C++ function polyroot;
#pragma link C++ function polyexpand;
#pragma link C++ function window_factory(const std::string&, size_t);
#pragma link C++ function window_factory_1(const std::string&, size_t, double);


#pragma link C++ defined_in "iirutil.hh";
#pragma link C++ class FilterParse;

#endif
